component entityName="Car" table="Car" persistent=true extends="CarTracker.models.orm.Base" {
	//property name="log" inject="coldbox:plugin:logger" persistent="false" scope="this";
	// primary key
	property name="CarID" column="CarID" fieldtype="id" generator="increment";
	// non-relational columns
	property name="Description" column="Description" ormtype="string";
	property name="Year" column="Year" ormtype="integer";
	property name="ListPrice" column="ListPrice" ormtype="integer";
	property name="SalePrice" column="SalePrice" ormtype="integer";
	property name="AcquisitionDate" column="AcquisitionDate" ormtype="date";
	property name="SaleDate" column="SaleDate" ormtype="date";
	property name="StockNumber" column="StockNumber" ormtype="string";
	property name="Rating" column="Rating" ormtype="float" notnull="false" default="0.00";
	property name="VIN" column="VIN" ormtype="string";
	property name="Fuel" column="Fuel" ormtype="string";
	property name="Engine" column="Engine" ormtype="string";
	property name="Transmission" column="Transmission" ormtype="string";
	property name="Mileage" column="Mileage" ormtype="integer";
	property name="IsSold" column="IsSold" ormtype="boolean" default="0";
	property name="Active" column="Active" ormtype="boolean" default="1";
	// one-to-one
	
	// one-to-many
	property name="Images" singularname="Image" fieldtype="one-to-many" cfc="CarTracker.models.orm.Image" fkcolumn="CarID" inverse=true cascade="all-delete-orphan";
	// many-to-one
	property name="Status" column="StatusID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.Status" fkcolumn="StatusID" lazy="true";
	property name="Make" column="MakeID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.Make" fkcolumn="MakeID" lazy="true";
	property name="Model" column="ModelID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.Model" fkcolumn="ModelID" lazy="true";
	property name="Category" column="CategoryID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.Category" fkcolumn="CategoryID" lazy="true";
	property name="Color" column="ColorID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.Color" fkcolumn="ColorID" lazy="true";
	property name="DriveTrain" column="DriveTrainID" fieldtype="many-to-one" cfc="CarTracker.models.orm.option.DriveTrain" fkcolumn="DriveTrainID" lazy="true";
	// many-to-many
	property name="SalesPeople" singularname="SalesPerson" fieldtype="many-to-many" cfc="CarTracker.models.orm.Staff" linktable="CarStaff" fkcolumn="CarID" inversejoincolumn="StaffID" lazy="extra";
	property name="Features" singularname="Feature" fieldtype="many-to-many" cfc="CarTracker.models.orm.option.Feature" linktable="CarFeature" fkcolumn="CarID" inversejoincolumn="FeatureID" lazy="extra";
	property name="ActiveFeatures" singularname="ActiveFeature" fieldtype="many-to-many" cfc="CarTracker.models.orm.option.Feature" linktable="CarFeature" fkcolumn="CarID" inversejoincolumn="FeatureID" lazy="extra" where="Active=1";
	// calculated properties
	property name="_Make" formula="SELECT m.LongName FROM Make m WHERE m.MakeID = MakeID";
	property name="_Model" formula="SELECT m.LongName FROM Model m WHERE m.ModelID = ModelID";
	property name="_Category" formula="SELECT c.LongName FROM Category c WHERE c.CategoryID = CategoryID";
	property name="_Status" formula="SELECT s.LongName FROM Status s WHERE s.StatusID = StatusID";
	property name="_Color" formula="SELECT c.LongName FROM Color c WHERE c.ColorID = ColorID";
	// non-persistent properties

	// object constraints
	this.constraints = {
		"Year" = { required=true, requiredMessage="Please enter a Year" },
		"ListPrice" = { required=true, requiredMessage="Please enter a List Price" },
		"AcquisitionDate" = { required=true, requiredMessage="Please enter an Acquisition Date", type="date", typeMessage="Please enter a valid Acquisition Date" },
		"SaleDate" = { type="date", typeMessage="Please enter a valid Sale Date" }
	};
	
	// methods
	public Car function init() {
		return this;
	}

	function postNew() {
		setSaleDate( now() );
	}
} 